(* Delphi Dialog
   Input text for WinPlot (opt. char table)
   =======================================

    J. Rathlev, IEAP, Uni-Kiel, (rathlev(a)physik.uni-kiel.de)

   The contents of this file may be used under the terms of the
   Mozilla Public License ("MPL") or
   GNU Lesser General Public License Version 2 or later (the "LGPL")

   Software distributed under this License is distributed on an "AS IS" basis,
   WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
   the specific language governing rights and limitations under the License.

   Vers. 1 - Jul. 2007
   *)

unit PlotTextDlg;

interface

uses Windows, SysUtils, Classes, Graphics, Forms, Controls, StdCtrls,
  Buttons, ExtCtrls;

type
  TPlotTextDialog = class(TForm)
    OKBtn: TBitBtn;
    CancelBtn: TBitBtn;
    Descriptor: TLabel;
    TextFeld: TEdit;
    CharTabBtn: TBitBtn;
    HochBtn: TSpeedButton;
    TiefBtn: TSpeedButton;
    procedure CharTabBtnClick(Sender: TObject);
    procedure HochBtnClick(Sender: TObject);
    procedure TiefBtnClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

(* Txt eingeben, Ergebnis: "true" bei "ok" *)
function GetPlotText(Pos        : TPoint;
                     Titel,Desc : string;
                     ShowTable  : boolean;
                     AFontName  : TFontName;
                     var AText  : string) : boolean;

var
  PlotTextDialog: TPlotTextDialog;

implementation

{$R *.DFM}

uses CharTableDlg;

{ ------------------------------------------------------------------- }
procedure TPlotTextDialog.CharTabBtnClick(Sender: TObject);
var
  c : char;
begin
  with TextFeld do begin
    c:=CharFromTable (Font.Name);
    if c>#0 then SelText:=c;
    SetFocus; // SelStart:=SelLength;
    end;
  end;

procedure TPlotTextDialog.HochBtnClick(Sender: TObject);
begin
  with TextFeld do begin
    if SelLength= 0 then SelText:='^'
    else SelText:='^'+SelText+'_';
    SetFocus;
    end;
  end;

procedure TPlotTextDialog.TiefBtnClick(Sender: TObject);
begin
  with TextFeld do begin
    if SelLength= 0 then SelText:='_'
    else SelText:='_'+SelText+'^';
    SetFocus;
    end;
  end;

{ ------------------------------------------------------------------- }
(* Txt eingeben, Ergebnis: "true" bei "ok" *)
function GetPlotText(Pos        : TPoint;
                     Titel,Desc : string;
                     ShowTable  : boolean;
                     AFontName  : TFontName;
                     var AText  : string) : boolean;
begin
  if not assigned(PlotTextDialog) then PlotTextDialog:=TPlotTextDialog.Create(Application);
  with PlotTextDialog do begin
    Left:=Pos.x; Top:=Pos.y;
    Caption:=Titel;
    Descriptor.Caption:=Desc;
    CharTabBtn.Visible:=ShowTable;
    with TextFeld do begin
      Font.Name:=AFontName;
      Text:=AText;
      end;
    if ShowModal=mrOK then begin
      AText:=TextFeld.Text;
      Result:=true;
      end
    else Result:=false;
    Release;
    end;
  PlotTextDialog:=nil;
  end;

end.
